<?php
namespace Odhen\API\Service;

use Zeedhi\Framework\Remote\cURLRequest;
use Odhen\API\Util\Exception;



class FiscalSantaCatarina {

    protected $curl;
    protected $workFolder;

    public function __construct() {
        $this->workFolder = $this->getWorkfolder();
    }

    const EVENT_VENDAS_CPF_CNPJ = '/VendasCPFCNPJ';
    const EVENT_REGISTRO_PAF = '/RegistroPaf';
    const EVENT_REQUISICAO_EXTERNA = '/RequisicaoExterna';


    public function createCurlObject($timeout) {
        $this->curl = new cURLRequest(null, curlRequest::METHOD_POST, array(
            CURLOPT_CONNECTTIMEOUT => 5,
            // Rota do RegistroPaf demorou cerca de 6 minutos nos testes realizados em bases com muitas informações.
            CURLOPT_CONNECTTIMEOUT => $timeout
        ));
        $this->curl->setHeaders(array(
            cURLRequest::CONTENT_TYPE_HEADER => cURLRequest::CONTENT_TYPE_APPLICATION_JSON
        ));
    }

    public function getWorkfolder() {
        $document_root = $_SERVER['DOCUMENT_ROOT'];
        $slashs = ['/', '\\'];
        return str_replace($slashs, DIRECTORY_SEPARATOR, $document_root);
    }

    public function setCurlUrl($DSSATHOST) {
        $this->curl->setBaseUrl($DSSATHOST);
    }

    public function createPath($paths) {
        $logDir = $this->workFolder . DIRECTORY_SEPARATOR;

        foreach($paths as $path) {
            $logDir = $logDir . $path;

            if(!is_dir($logDir)) {
                mkdir($logDir, 0777);
            }
        }
    }


    public function vendasCPFCNPJ($CDFILIAL, $CPFCNPJ, $PERIODO, $NMAPP, $VERSAOAPP) {
        try {

            $params = array(
                'stCdFilial' => $CDFILIAL,
                'stCPFCNPJ' => $CPFCNPJ,
                'stPeriodo' => $PERIODO,
                'stNmApp' => $NMAPP,
                'stVersaoApp' => $VERSAOAPP,
                'stDir' => $this->workFolder . DIRECTORY_SEPARATOR . 'relatoriosFiscais' . DIRECTORY_SEPARATOR . $NMAPP . DIRECTORY_SEPARATOR .  'Filial - ' . $CDFILIAL . DIRECTORY_SEPARATOR,
                'stArquivo' => 'VendasCPFCPNJ_' . date('d-m-Y') .  '.txt'
            );

            $paths = ['relatoriosFiscais' . DIRECTORY_SEPARATOR, $NMAPP . DIRECTORY_SEPARATOR,  'Filial - ' . $CDFILIAL . DIRECTORY_SEPARATOR];
            $this->createPath($paths);

            $respostaSALE = $this->curl->request(self::EVENT_VENDAS_CPF_CNPJ, $params);
            $respostaSALE = json_decode($respostaSALE, true);

            if (!array_key_exists('error', $respostaSALE) || !array_key_exists('data', $respostaSALE) || !array_key_exists('message', $respostaSALE)) {
                $respostaSALE = array(
                    'error' => true,
                    'message' => 'Erro ao gerar o relatório de Vendas por CPF/CNPJ.<br><br> Não foi possível obter o retorno do serviço periféricos.'
                );
            }
            
        } catch(\Exception $e) {
            Exception::logException($e, Exception::LOG_TYPES['EXCEPTION_LOG']);
            $msg = $e->getMessage();
            $pattern = '/Connection refused/';
            if (preg_match($pattern, $msg)) {
                $msg = 'Endereço do Periféricos inválido ou se encontra desligado.';
            }

            $respostaSALE = array(
                'error' => true,
                'message' => 'Erro ao gerar o relatório Vendas por CPF/CNPJ.<br> Mensagem de retorno: <br><br>' . $msg
            );
        }
        return $respostaSALE;
    }

    public function registroPaf($CDFILIAL, $CDCAIXA, $DATAINI, $DATAFIM, $NMAPP) {
       try {

            $params = array(
                'stCdFilial' => $CDFILIAL,
                'stCdCaixa' => $CDCAIXA,
                'stDataIni' => $DATAINI,
                'stDataFim' => $DATAFIM,
                'stDir' => $this->workFolder . DIRECTORY_SEPARATOR . 'relatoriosFiscais' . DIRECTORY_SEPARATOR. $NMAPP . DIRECTORY_SEPARATOR. 'Filial - ' . $CDFILIAL . DIRECTORY_SEPARATOR. 'Caixa - ' . $CDCAIXA . DIRECTORY_SEPARATOR,
                'stArquivo' => 'RegistroPaf_' . date('d-m-Y') .  '.txt'
            );
            
            $paths = ['relatoriosFiscais' . DIRECTORY_SEPARATOR, $NMAPP . DIRECTORY_SEPARATOR, 'Filial - ' . $CDFILIAL . DIRECTORY_SEPARATOR, 'Caixa - ' . $CDCAIXA . DIRECTORY_SEPARATOR];
            $this->createPath($paths);

            $respostaSALE = $this->curl->request(self::EVENT_REGISTRO_PAF, $params);
            $respostaSALE = json_decode($respostaSALE, true);

            if (!array_key_exists('error', $respostaSALE) || !array_key_exists('data', $respostaSALE) || !array_key_exists('message', $respostaSALE)) {
                $respostaSALE = array(
                    'error' => true,
                    'message' => 'Erro ao gerar o relatório Registro Paf.<br><br> Não foi possível obter o retorno do serviço periféricos.'
                );
            }
            
        } catch(\Exception $e) {
            Exception::logException($e, Exception::LOG_TYPES['EXCEPTION_LOG']);
            $msg = $e->getMessage();
            $pattern = '/Connection refused/';
            if (preg_match($pattern, $msg)) {
                $msg = 'Endereço do Periféricos inválido ou se encontra desligado.';
            }

            $respostaSALE = array(
                'error' => true,
                'message' => 'Erro ao gerar o relatório Registro Paf.<br> Mensagem de retorno: <br><br>' . $msg
            );
        }
        return $respostaSALE;
    }

    public function requisicaoExterna($CDFILIAL, $DATAINI, $DATAFIM, $NMAPP, $VERSAOAPP) {
       try {

            $params = array(
                'stCdFilial' => $CDFILIAL,
                'stDataIni' => $DATAINI,
                'stDataFim' => $DATAFIM,
                'stNmApp' => $NMAPP,
                'stVersaoApp' => $VERSAOAPP,
                'stDir' => $this->workFolder . DIRECTORY_SEPARATOR . 'relatoriosFiscais' . DIRECTORY_SEPARATOR . $NMAPP . DIRECTORY_SEPARATOR . 'Filial - ' . $CDFILIAL . DIRECTORY_SEPARATOR,
                'stArquivo' => 'RequisicaoExterna_' . date('d-m-Y') .  '.txt'
            );

            $paths = ['relatoriosFiscais' . DIRECTORY_SEPARATOR, $NMAPP . DIRECTORY_SEPARATOR, 'Filial - ' . $CDFILIAL . DIRECTORY_SEPARATOR];
            $this->createPath($paths);

            $respostaSALE = $this->curl->request(self::EVENT_REQUISICAO_EXTERNA, $params);
            $respostaSALE = json_decode($respostaSALE, true);

            if (!array_key_exists('error', $respostaSALE) || !array_key_exists('data', $respostaSALE) || !array_key_exists('message', $respostaSALE)) {
                $respostaSALE = array(
                    'error' => true,
                    'message' => 'Erro ao gerar o relatório das Requisicao Externas.<br><br> Não foi possível obter o retorno do serviço periféricos.'
                );
            }
            
        } catch(\Exception $e) {
            Exception::logException($e, Exception::LOG_TYPES['EXCEPTION_LOG']);
            $msg = $e->getMessage();
            $pattern = '/Connection refused/';
            if (preg_match($pattern, $msg)) {
                $msg = 'Endereço do Periféricos inválido ou se encontra desligado.';
            }
            
            $respostaSALE = array(
                'error' => true,
                'message' => 'Erro ao gerar o relatório das Requisicao Externas.<br> Mensagem de retorno: <br><br>' . $msg
            );
        }
        return $respostaSALE;
    }

}

